@@ -13,7 +13,6 @@
 #define GTK_THEME_KEY "X-GNOME-Metatheme/GtkTheme"
 #define GTK_COLOR_SCHEME_KEY "X-GNOME-Metatheme/GtkColorScheme"
 #define METACITY_THEME_KEY "X-GNOME-Metatheme/MetacityTheme"
-#define SAWFISH_THEME_KEY "X-GNOME-Metatheme/SawfishTheme"
 #define ICON_THEME_KEY "X-GNOME-Metatheme/IconTheme"
 #define SOUND_THEME_KEY "X-GNOME-Metatheme/SoundTheme"
 #define APPLICATION_FONT_KEY "X-GNOME-Metatheme/ApplicationFont"
@@ -32,7 +31,7 @@
 
 typedef struct _ThemeCallbackData
 {
-  GFunc func;
+  ThemeChangedCallback func;
   gpointer data;
 } ThemeCallbackData;
 
@@ -53,7 +52,7 @@ typedef struct {
   GHashTable *handle_hash;
   gint priority;
 } CallbackTuple;
-  
+
 
 /* Hash tables */
 
@@ -84,13 +83,10 @@ static gint
 safe_strcmp (const gchar *a_str,
 	     const gchar *b_str)
 {
-  if (a_str == NULL && b_str != NULL)
-    return -1;
-  if (a_str != NULL && b_str == NULL)
-    return 1;
-  if (a_str == NULL && b_str == NULL)
-    return 0;
-  return strcmp (a_str, b_str);
+  if (a_str && b_str)
+    return strcmp (a_str, b_str);
+  else
+    return a_str - b_str;
 }
 
 static gint
@@ -109,7 +105,7 @@ get_priority_from_data_by_hash (GHashTable *hash_table,
 
   return theme_priority;
 }
-     
+
 
 static void
 add_data_to_hash_by_name (GHashTable  *hash_table,
@@ -171,7 +167,7 @@ remove_data_from_hash_by_name (GHashTable  *hash_table,
     g_hash_table_remove (hash_table, name);
   else
     g_hash_table_insert (hash_table, g_strdup (name), list);
-    
+
 }
 
 static gpointer
@@ -193,7 +189,7 @@ get_data_from_hash_by_name (GHashTable  *hash_table,
     }
   while (list)
     {
-      gint theme_priority ;
+      gint theme_priority;
 
       theme_priority = get_priority_from_data_by_hash (hash_table, list->data);
 
@@ -203,8 +199,8 @@ get_data_from_hash_by_name (GHashTable  *hash_table,
       list = list->next;
     }
   return NULL;
-}  
-  
+}
+
 GnomeThemeMetaInfo *
 gnome_theme_read_meta_theme (GnomeVFSURI *meta_theme_uri)
 {
@@ -223,7 +219,7 @@ gnome_theme_read_meta_theme (GnomeVFSURI *meta_theme_uri)
       return NULL;
     }
   common_theme_dir_uri = gnome_vfs_uri_get_parent (meta_theme_uri);
-  
+
   meta_theme_info = gnome_theme_meta_info_new ();
   meta_theme_info->path = meta_theme_file;
   meta_theme_info->name = gnome_vfs_uri_extract_short_name (common_theme_dir_uri);
@@ -239,7 +235,7 @@ gnome_theme_read_meta_theme (GnomeVFSURI *meta_theme_uri)
          return NULL;
        }
      }
-     
+
   meta_theme_info->readable_name = g_strdup (str);
 
   str = gnome_desktop_item_get_localestring (meta_theme_ditem, THEME_COMMENT);
@@ -311,13 +307,13 @@ gnome_theme_read_meta_theme (GnomeVFSURI *meta_theme_uri)
   str = gnome_desktop_item_get_string (meta_theme_ditem, MONOSPACE_FONT_KEY);
   if (str != NULL)
     meta_theme_info->monospace_font = g_strdup (str);
-    
+
   str = gnome_desktop_item_get_string (meta_theme_ditem, BACKGROUND_IMAGE_KEY);
   if (str != NULL)
     meta_theme_info->background_image = g_strdup (str);
-  
+
   gnome_desktop_item_unref (meta_theme_ditem);
-  
+
   return meta_theme_info;
 }
 
@@ -345,10 +341,10 @@ read_icon_theme (GnomeVFSURI *icon_theme_uri)
       g_free (icon_theme_file);
       return NULL;
     }
-  hidden_theme_icon = gnome_desktop_item_get_string (icon_theme_ditem, "Icon Theme/Hidden");
 
-  if (hidden_theme_icon == NULL || 
-      strcmp (hidden_theme_icon, "false") == 0) 
+  hidden_theme_icon = gnome_desktop_item_get_string (icon_theme_ditem, "Icon Theme/Hidden");
+  if (hidden_theme_icon == NULL ||
+      strcmp (hidden_theme_icon, "false") == 0)
     {
       gchar *dir_name;
       icon_theme_info = gnome_theme_icon_info_new ();
@@ -358,11 +354,10 @@ read_icon_theme (GnomeVFSURI *icon_theme_uri)
       icon_theme_info->name = g_path_get_basename (dir_name);
       g_free (dir_name);
     }
-  else 
+  else
     {
-      gnome_desktop_item_unref (icon_theme_ditem);
+      icon_theme_info = NULL;
       g_free (icon_theme_file);
-      return NULL;
     }
 
   gnome_desktop_item_unref (icon_theme_ditem);
@@ -380,27 +375,17 @@ handle_change_signal (GnomeThemeType       type,
   gchar *type_str = NULL;
   gchar *element_str = NULL;
 #endif
-  gchar *uri = NULL;
   GList *list;
 
   if (initting)
     return;
 
-  if (type == GNOME_THEME_TYPE_REGULAR)
-    uri = g_strdup (((GnomeThemeInfo *)theme)->path);
-  else if (type == GNOME_THEME_TYPE_METATHEME)
-    uri = g_strdup (((GnomeThemeMetaInfo *)theme)->path);
-  else if (type == GNOME_THEME_TYPE_ICON)
-    uri = g_strdup (((GnomeThemeIconInfo *)theme)->path);
-  
   for (list = callbacks; list; list = list->next)
   {
     ThemeCallbackData *callback_data = list->data;
-    (* callback_data->func) (uri, callback_data->data);
+    (* callback_data->func) (type, theme, change_type, element, callback_data->data);
   }
 
-  g_free (uri);
-
 #ifdef DEBUG
   if (change_type == GNOME_THEME_CHANGE_CREATED)
     type_str = "created";
@@ -415,7 +400,7 @@ handle_change_signal (GnomeThemeType       type,
     element_str = "keybinding";
   if (element & GNOME_THEME_METACITY)
     element_str = "metacity";
-  
+
   if (type == GNOME_THEME_TYPE_REGULAR)
     {
       g_print ("theme \"%s\" has a theme of type %s (priority %d) has been %s\n",
@@ -459,10 +444,7 @@ update_theme_index (GnomeVFSURI       *index_uri,
    * sophisticated a test than "files exists and is a file" */
   file_info = gnome_vfs_file_info_new ();
   result = gnome_vfs_get_file_info_uri (index_uri, file_info, GNOME_VFS_FILE_INFO_FOLLOW_LINKS);
-  if (result == GNOME_VFS_OK && file_info->type == GNOME_VFS_FILE_TYPE_REGULAR)
-    theme_exists = TRUE;
-  else
-    theme_exists = FALSE;
+  theme_exists = (result == GNOME_VFS_OK && file_info->type == GNOME_VFS_FILE_TYPE_REGULAR);
   gnome_vfs_file_info_unref (file_info);
 
   /* Next, we see what currently exists */
@@ -494,7 +476,7 @@ update_theme_index (GnomeVFSURI       *index_uri,
   else
     {
       gboolean theme_used_to_exist = FALSE;
-      
+
       if (key_element & GNOME_THEME_GTK_2)
 	{
 	  theme_used_to_exist = theme_info->has_gtk;
@@ -525,7 +507,7 @@ update_theme_index (GnomeVFSURI       *index_uri,
 	{
 	  handle_change_signal (GNOME_THEME_TYPE_REGULAR, theme_info, GNOME_THEME_CHANGE_CREATED, key_element);
 	}
-      else if (! theme_exists && theme_used_to_exist)
+      else if (!theme_exists && theme_used_to_exist)
 	{
 	  handle_change_signal (GNOME_THEME_TYPE_REGULAR, theme_info, GNOME_THEME_CHANGE_DELETED, key_element);
 	}
@@ -781,7 +763,7 @@ metacity_dir_changed (GnomeVFSMonitorHandle *handle,
   CommonThemeDirMonitorData *monitor_data;
 
   monitor_data = user_data;
-  
+
   metacity_dir_uri = gnome_vfs_uri_new (info_uri);
   affected_file = gnome_vfs_uri_extract_short_name (metacity_dir_uri);
 
@@ -1289,7 +1271,6 @@ gnome_theme_info_find_by_uri (const gchar *theme_uri)
   return g_hash_table_lookup (theme_hash_by_uri, theme_uri);
 }
 
-
 /* Icon themes */
 GnomeThemeIconInfo *
 gnome_theme_icon_info_new (void)
@@ -1305,6 +1286,7 @@ void
 gnome_theme_icon_info_free (GnomeThemeIconInfo *icon_theme_info)
 {
   g_free (icon_theme_info->name);
+  g_free (icon_theme_info->readable_name);
   g_free (icon_theme_info->path);
   g_free (icon_theme_info);
 }
@@ -1374,7 +1356,7 @@ gnome_theme_meta_info_free (GnomeThemeMetaInfo *meta_theme_info)
   g_free (meta_theme_info->gtk_color_scheme);
   g_free (meta_theme_info->icon_theme_name);
   g_free (meta_theme_info->metacity_theme_name);
-  
+
   g_free (meta_theme_info);
 }
 
@@ -1466,12 +1448,9 @@ gnome_theme_meta_info_compare (GnomeThemeMetaInfo *a,
   cmp = safe_strcmp (a->icon_theme_name, b->icon_theme_name);
   if (cmp != 0) return cmp;
 
-  cmp = safe_strcmp (a->sawfish_theme_name, b->sawfish_theme_name);
-  if (cmp != 0) return cmp;
-
   cmp = safe_strcmp (a->sound_theme_name, b->sound_theme_name);
   if (cmp != 0) return cmp;
-  
+
   cmp = safe_strcmp (a->application_font, b->application_font);
   if (cmp != 0) return cmp;
 
@@ -1484,8 +1463,50 @@ gnome_theme_meta_info_compare (GnomeThemeMetaInfo *a,
   return safe_strcmp (a->background_image, b->background_image);
 }
 
+gboolean
+gnome_theme_is_writable (gpointer theme, GnomeThemeType type) {
+  GnomeVFSResult vfs_result;
+  GnomeVFSFileInfo *vfs_info;
+  const gchar *theme_path;
+  gboolean writable;
+
+  if (theme == NULL)
+    return FALSE;
+
+  switch (type) {
+    case GNOME_THEME_TYPE_REGULAR:
+      theme_path = ((GnomeThemeInfo *) theme)->path;
+      break;
+    case GNOME_THEME_TYPE_ICON:
+      theme_path = ((GnomeThemeIconInfo *) theme)->path;
+      break;
+    case GNOME_THEME_TYPE_METATHEME:
+      theme_path = ((GnomeThemeMetaInfo *) theme)->path;
+      break;
+    default:
+      g_assert_not_reached ();
+      break;
+  }
+
+  if (theme_path == NULL)
+    return FALSE;
+
+  vfs_info = gnome_vfs_file_info_new ();
+  vfs_result = gnome_vfs_get_file_info (theme_path,
+					vfs_info,
+					GNOME_VFS_FILE_INFO_GET_ACCESS_RIGHTS);
+
+  writable = ((vfs_result == GNOME_VFS_OK) &&
+              (vfs_info->valid_fields & GNOME_VFS_FILE_INFO_FIELDS_ACCESS) &&
+              (vfs_info->permissions & GNOME_VFS_PERM_ACCESS_WRITABLE));
+
+  gnome_vfs_file_info_unref (vfs_info);
+
+  return writable;
+}
+
 void
-gnome_theme_info_register_theme_change (GFunc    func,
+gnome_theme_info_register_theme_change (ThemeChangedCallback func,
 					gpointer data)
 {
   ThemeCallbackData *callback_data;
